==> phpicalendar-2.1.tgz: phpicalendar/languages/lithuanian.inc.php <==
<?php

// Lithuanian language include
// For version 2.0 PHP iCalendar
//
// Translation by Rima Kurtinaitienė rimaiste at hotmail dot com
//


$lang['l_day'] 			= 'Diena';
$lang['l_week']			= 'Savaitė';
$lang['l_month']		= 'Mėnuo';
$lang['l_year'] 		= 'Metai';
$lang['l_calendar'] 		= 'kalendorius';
$lang['l_next_day'] 		= 'Kita diena';
$lang['l_next_month'] 		= 'Kitas mėnuo';
$lang['l_next_week'] 		= 'Kita savaitė';
$lang['l_next_year'] 		= 'Kiti metai';
$lang['l_last_day'] 		= 'Ankstesnė diena';
$lang['l_last_month'] 		= 'Ankstesnis mėnuo';
$lang['l_last_week'] 		= 'Ankstesnė savaitė';
$lang['l_last_year'] 		= 'Ankstesni metai';
$lang['l_subscribe'] 		= 'Užsiregistruoti';
$lang['l_download'] 		= 'Išsisaugoti';
$lang['l_powered_by'] 		= 'Naudojamas:';
$lang['l_event'] 			= 'Renginiai';
$lang['l_event_start'] 		= 'Pradžia';
$lang['l_event_end'] 		= 'Pabaiga';
$lang['l_this_months'] 		= 'Šio mėnesio renginiai';
$lang['l_date'] 			= 'Data';
$lang['l_summary'] 			= 'Santrauka';
$lang['l_all_day'] 			= 'Renginys trunka visą dieną';
$lang['l_notes'] 			= 'Pastabos';
$lang['l_this_years'] 		= 'Šių metų renginiai';
$lang['l_today'] 			= 'Šiandien';
$lang['l_this_week'] 		= 'Šią savaitę';
$lang['l_this_month'] 		= 'Šį mėnesį';
$lang['l_jump'] 			= 'Pereiti į';
$lang['l_tomorrows'] 		= 'Rytdienos renginiai';
$lang['l_goday'] 			= 'Pereiti į šiandieną';
$lang['l_goweek'] 			= 'Pereiti į šią savaitę';
$lang['l_gomonth'] 			= 'Pereiti į šį mėnesį';
$lang['l_goyear'] 			= 'Pereiti į šiuos metus';
$lang['l_search'] 			= 'Ieškoti'; // the verb
$lang['l_results'] 			= 'Paieškos rezultatai';
$lang['l_query'] 			= 'Užklausa'; // will be followed by the search query
$lang['l_no_results'] 		= 'Neradome jokių renginių';
$lang['l_goprint'] 			= 'Spausdinimui';
$lang['l_time'] 			= 'Laikas';
$lang['l_summary'] 			= 'Pavadinimas';
$lang['l_description'] 		= 'Aprašymas';
$lang['l_this_site_is']		= 'Šiame tinklalapyje yra:';
$lang['l_no_events_day']	= 'Šiandien renginių nėra.';
$lang['l_no_events_week']	= 'Šią savatę renginių nėra.';
$lang['l_no_events_month']	= 'Šį mėnesį renginių nėra.';
$lang['l_rss_day_date']		= 'G:i';  // Lists just the time
$lang['l_rss_week_date	']	= '%b %e d.';  // Lists just the day
$lang['l_rss_month_date	']	= '%b %e d.';  // Lists just the day
$lang['l_rss_language']		= 'lt-lt';
$lang['l_search_took']		= 'Paieška užtruko %s s';
$lang['l_recurring_event']	= 'Pasikartojantis renginys';
$lang['l_exception']		= 'Išimtys';
$lang['l_no_query']			= 'Nebuvo užklausos';
$lang['l_preferences']		= 'Nustatymai';
$lang['l_printer']			= 'Spausdintuvas';
$lang['l_select_lang']		= 'Pasirinkite standartinę kalbą';
$lang['l_select_cal']		= 'Pasirinkite standartinį kalendorių';
$lang['l_select_view']		= 'Pasirinkite standartinį kalendoriaus vaizdavimą';
$lang['l_select_time']		= 'Pasirinkite standartinį pradžios laiką';
$lang['l_select_day']		= 'Pasirinkite standartinę savaitės pradžią';
$lang['l_select_style']		= 'Pasirinkite standartinį stilių';
$lang['l_set_prefs']		= 'Patvirtinkite nustatymus';
$lang['l_completed_date']	= 'Atlikta';
$lang['l_completed']		= 'Baigta';
$lang['l_created']			= 'Sukurtas';
$lang['l_due']				= 'Numatytas';
$lang['l_priority']			= 'Pirmenybė';
$lang['l_priority_high']	= 'Aukšta';
$lang['l_priority_low']		= 'Žema';
$lang['l_priority_medium']	= 'Vidutinė';
$lang['l_priority_none']	= 'Jokia';
$lang['l_status']			= 'Būklė';
$lang['l_todo']				= 'Užduotys';
$lang['l_unfinished']		= 'Nebaigtos';
$lang['l_prefs_set'] 		= 'Jūsų pasirinkti nustatymai patvirtiniti.';
$lang['l_prefs_unset'] 		= 'Nustatymai nuimti. Pasikeitimus pamatysite pakrovę puslapį iš naujo.';
$lang['l_unset_prefs'] 		= 'Nuimti nustatymus';
$lang['l_organizer']		= 'Tvarkaraštis';
$lang['l_attendee']			= 'Dalyviai';
$lang['l_location']			= 'Vieta';
$lang['l_admin_header']		= 'PHP iCalendar Administravimas';
$lang['l_username']			= 'Vartotojo vardas';
$lang['l_password']			= 'Slaptažodis';
$lang['l_login']			= 'Prisijungti';
$lang['l_invalid_login']	= 'Neteisingas vartotojo vardas arba slaptažodis.';
$lang['l_addupdate_cal']	= 'Pridėti ar atnaujinti kalendorių';
$lang['l_addupdate_desc']	= 'Pridėti kalendorių perkopijuojant naują failą. Pridėti kalendorių naudojant tą patį failo vardą.';
$lang['l_delete_cal']		= 'Ištrinti kalendorių';
$lang['l_logout']			= 'Atsijungti';
$lang['l_cal_file']			= 'Kalendoriaus failas';
$lang['l_php_error']		= 'PHP klaida';
$upload_error_gen_lang		= 'Nepavyko nusiųsti failo į serverį.';
$upload_error_lang[0]		= 'Nepavyko nusiųsti failo į serverį.';
$upload_error_lang[1]		= 'Siunčiamas failas yra per didelis.';
$upload_error_lang[2]		= 'Siunčiamas failas yra per didelis.';
$upload_error_lang[3]		= 'Pavyko nusiųsti tik dalį failo.';
$upload_error_lang[4]		= 'Turite pasirinkti failą siuntimui.';
$lang['l_upload_error_type'] = 'Galima siųsti tik .ics failus.';
$lang['l_copy_error']			= 'Nepavyko nukopijuoti failo';
$lang['l_delete_error']			= 'Nepavyko ištrinti failo';
$lang['l_delete_success']		= 'buvo sėkmingai ištrintas.';
$lang['l_action_success']		= 'Veiksmas buvo sėkmingas.';
$lang['l_submit']				= 'Gerai';
$lang['l_delete']				= 'Ištrinti';
$all_cal_comb_lang			= 'Visi kalendoriai';

// New for 2.0
$lang['l_legend']			= 'Paaiškinimai';
$lang['l_admin_subhead']	= 'Šiame puslapyje tvarkykite savo kalendorius';
$lang['l_prefs_subhead']	= 'Nustato slapuką šio puslapio aplankymui';
$lang['l_rss_info']			= 'RSS Informacija';
$lang['l_rss_subhead']		= 'Pagrindiniai RSS vaizdai kiekvienam kalendoriui yra šie';
$lang['l_rss_notenabled']	= 'RSS šioje svetainėje neįjungtas';

// - navigation
$lang['l_back'] 		= 'Atgal';
$lang['l_next'] 		= 'Kitas';
$lang['l_prev'] 		= 'Ankstesnis';
$lang['l_day_view'] 	= 'Diena';
$lang['l_week_view'] 	= 'Savaitė';
$lang['l_month_view'] 	= 'Mėnuo';
$lang['l_year_view'] 	= 'Metai';

// ---------------------------------


// $format_recur, items enclosed in % will be substituted with variables
$format_recur_lang['delimiter']	= ', ';								// ie, 'one, two, three'

$format_recur_lang['yearly']		= array('metus','metus');		// for these, put singular
$format_recur_lang['monthly']		= array('mėnesį','mėnesius');		// and plural forms
$format_recur_lang['weekly']		= array('savaitę','savaites');		// these will be %freq%
$format_recur_lang['daily']			= array('dieną','dienas');			// in the replacement below
$format_recur_lang['hourly']		= array('valandą','valandas');
$format_recur_lang['minutely']		= array('minutę','minutes');
$format_recur_lang['secondly']		= array('sekundę','sekundes');

$format_recur_lang['start']			= 'Kas %int% %freq% %for%';	// ie, 'Every 1 day until January 4' or 'Every 1 day for a count of 5'
$format_recur_lang['until']			= 'iki %date%';				// ie, 'until January 4'
$format_recur_lang['count']			= '%int% kartus';		// ie, 'for 5 times'

$format_recur_lang['bymonth']		= 'Mėnesiais: %list%';			// ie, 'In months: January, February, March'
$format_recur_lang['bymonthday']	= 'Mėnesio dienomis: %list%';			// ie, 'On dates: 1, 2, 3, 4'
$format_recur_lang['byday']			= 'Savaitės dienomis: %list%';			// ie, 'On days: Mon, Tues, Wed, Thurs'

// ---------------------------------

$daysofweek_lang			= array ('Sekmadienis','Pirmadienis','Antradienis','Trečiadienis','Ketvirtadienis','Penktadienis','Šeštadienis');
$daysofweekshort_lang		= array ('Sk','Pr','An','Tr','Kt','Pn','Št');
$daysofweekreallyshort_lang	= array ('S','P','A','T','K','P','Š');
$monthsofyear_lang			= array ('Sausio','Vasario','Kovo','Balandžio','Gegužės','Birželio','Liopos','Rugpjūčio','Rugsėjo','Spalio','Lapkričio','Gruodžio');
$monthsofyearshort_lang		= array ('Sau','Vas','Kov','Bal','Geg','Bir','Lie','Rgp','Rgs','Spa','Lap','Gru');

// For time formatting, check out: http://www.php.net/manual/en/function.date.php
$timeFormat = 'G:i';
$timeFormat_small = 'G:i';

// For date formatting, see note below
$dateFormat_day = '%A, %B %e d.';
$dateFormat_week = '%B %e d.';
$dateFormat_week_list = '%b %e d., %a';
$dateFormat_week_jump = '%b %e d.';
$dateFormat_month = '%Y m. %b mėn.';
$dateFormat_month_list = '%A, %B %e d.';

/*
Notes about dateFormat_*
	The pieces are similar to that of the PHP function strftime(), 
	however only the following is supported at this time:
	
	%A - the full week day name as specified in $daysofweek_lang
	%a - the shortened week day name as specified in $daysofweekshort_lang
	%B - the full month name as specified in $monthsofyear_lang
	%b - the shortened month name as specified in $monthsofyearshort_lang
	%e - the day of the month as a decimal number (1 to 31)
	%Y - the 4-digit year

	If this causes problems with representing your language accurately, let
	us know. We will be happy to modify this if needed.
*/

// Error messages - %s will be replaced with a variable
$lang['l_error_title'] 			= 'Klaida!';
$lang['l_error_window'] 		= 'Įvyko klaida!';
$lang['l_error_calendar'] 		= 'Kalendorius "%s" buvo keičiamas, kai ši klaida įvyko.';
$lang['l_error_path'] 			= 'Nerastas toks kelias: "%s"';
$lang['l_error_back'] 			= 'Norėdami grįžti atgal, apauskite "Back".';
$lang['l_error_remotecal'] 		= 'Serveris nepriima nutolusių nepatvirtintų kalendorių.';
$lang['l_error_restrictedcal'] 	= 'Pabandėte pasiekti uždraustą kalendorių šiame serveryje.';
$lang['l_error_invalidcal'] 	= 'kalendoriaus failas. Pabandykite kitą.';
$lang['l_error_cantopen'] 		= 'Nepavyko atidaryti kalendoriaus.';
$lang['l_error_cache']			= 'Nepavyko rašyti į kešo katalogą. Pasitikrinkite konfigūraciją.';

?>

==> phpicalendar-2.31p2.tgz: phpicalendar/languages/lithuanian.inc.php <==
<?php

// Lithuanian language include
// For version 2.0 PHP iCalendar
//
// Translation by Rima Kurtinaitienė rimaiste at hotmail dot com
//


$lang['l_day'] 			= 'Diena';
$lang['l_week']			= 'Savaitė';
$lang['l_month']		= 'Mėnuo';
$lang['l_year'] 		= 'Metai';
$lang['l_calendar'] 		= 'kalendorius';
$lang['l_next_day'] 		= 'Kita diena';
$lang['l_next_month'] 		= 'Kitas mėnuo';
$lang['l_next_week'] 		= 'Kita savaitė';
$lang['l_next_year'] 		= 'Kiti metai';
$lang['l_last_day'] 		= 'Ankstesnė diena';
$lang['l_last_month'] 		= 'Ankstesnis mėnuo';
$lang['l_last_week'] 		= 'Ankstesnė savaitė';
$lang['l_last_year'] 		= 'Ankstesni metai';
$lang['l_subscribe'] 		= 'Užsiregistruoti';
$lang['l_download'] 		= 'Išsisaugoti';
$lang['l_powered_by'] 		= 'Naudojamas:';
$lang['l_event'] 			= 'Renginiai';
$lang['l_event_start'] 		= 'Pradžia';
$lang['l_event_end'] 		= 'Pabaiga';
$lang['l_this_months'] 		= 'Šio mėnesio renginiai';
$lang['l_date'] 			= 'Data';
$lang['l_summary'] 			= 'Santrauka';
$lang['l_all_day'] 			= 'Renginys trunka visą dieną';
$lang['l_notes'] 			= 'Pastabos';
$lang['l_this_years'] 		= 'Šių metų renginiai';
$lang['l_today'] 			= 'Šiandien';
$lang['l_this_week'] 		= 'Šią savaitę';
$lang['l_this_month'] 		= 'Šį mėnesį';
$lang['l_jump'] 			= 'Pereiti į';
$lang['l_tomorrows'] 		= 'Rytdienos renginiai';
$lang['l_goday'] 			= 'Pereiti į šiandieną';
$lang['l_goweek'] 			= 'Pereiti į šią savaitę';
$lang['l_gomonth'] 			= 'Pereiti į šį mėnesį';
$lang['l_goyear'] 			= 'Pereiti į šiuos metus';
$lang['l_search'] 			= 'Ieškoti'; // the verb
$lang['l_results'] 			= 'Paieškos rezultatai';
$lang['l_pick_multiple'] 	= 'Pick multiple';
$lang['l_query'] 			= 'Užklausa'; // will be followed by the search query
$lang['l_no_results'] 		= 'Neradome jokių renginių';
$lang['l_goprint'] 			= 'Spausdinimui';
$lang['l_time'] 			= 'Laikas';
$lang['l_summary'] 			= 'Pavadinimas';
$lang['l_description'] 		= 'Aprašymas';
$lang['l_this_site_is']		= 'Šiame tinklalapyje yra:';
$lang['l_no_events_day']	= 'Šiandien renginių nėra.';
$lang['l_no_events_week']	= 'Šią savatę renginių nėra.';
$lang['l_no_events_month']	= 'Šį mėnesį renginių nėra.';
$lang['l_rss_day_date']		= 'G:i';  // Lists just the time
$lang['l_rss_week_date	']	= '%b %e d.';  // Lists just the day
$lang['l_rss_month_date	']	= '%b %e d.';  // Lists just the day
$lang['l_rss_language']		= 'lt-lt';
$lang['l_search_took']		= 'Paieška užtruko %s s';
$lang['l_recurring_event']	= 'Pasikartojantis renginys';
$lang['l_exception']		= 'Išimtys';
$lang['l_no_query']			= 'Nebuvo užklausos';
$lang['l_preferences']		= 'Nustatymai';
$lang['l_printer']			= 'Spausdintuvas';
$lang['l_select_lang']		= 'Pasirinkite standartinę kalbą';
$lang['l_select_cal']		= 'Pasirinkite standartinį kalendorių';
$lang['l_select_view']		= 'Pasirinkite standartinį kalendoriaus vaizdavimą';
$lang['l_select_time']		= 'Pasirinkite standartinį pradžios laiką';
$lang['l_select_day']		= 'Pasirinkite standartinę savaitės pradžią';
$lang['l_select_style']		= 'Pasirinkite standartinį stilių';
$lang['l_set_prefs']		= 'Patvirtinkite nustatymus';
$lang['l_completed_date']	= 'Atlikta';
$lang['l_completed']		= 'Baigta';
$lang['l_created']			= 'Sukurtas';
$lang['l_due']				= 'Numatytas';
$lang['l_priority']			= 'Pirmenybė';
$lang['l_priority_high']	= 'Aukšta';
$lang['l_priority_low']		= 'Žema';
$lang['l_priority_medium']	= 'Vidutinė';
$lang['l_priority_none']	= 'Jokia';
$lang['l_status']			= 'Būklė';
$lang['l_status_confirmed'] = 'CONFIRMED' ; 
$lang['l_status_cancelled'] = 'CANCELLED'; 
$lang['l_status_tentative'] = 'TENTATIVE'; 
$lang['l_todo']				= 'Užduotys';
$lang['l_unfinished']		= 'Nebaigtos';
$lang['l_prefs_set'] 		= 'Jūsų pasirinkti nustatymai patvirtiniti.';
$lang['l_prefs_unset'] 		= 'Nustatymai nuimti. Pasikeitimus pamatysite pakrovę puslapį iš naujo.';
$lang['l_unset_prefs'] 		= 'Nuimti nustatymus';
$lang['l_organizer']		= 'Tvarkaraštis';
$lang['l_attendee']			= 'Dalyviai';
$lang['l_location']			= 'Vieta';
$lang['l_admin_header']		= 'PHP iCalendar Administravimas';
$lang['l_username']			= 'Vartotojo vardas';
$lang['l_password']			= 'Slaptažodis';
$lang['l_login']			= 'Prisijungti';
$lang['l_invalid_login']	= 'Neteisingas vartotojo vardas arba slaptažodis.';
$lang['l_addupdate_cal']	= 'Pridėti ar atnaujinti kalendorių';
$lang['l_addupdate_desc']	= 'Pridėti kalendorių perkopijuojant naują failą. Pridėti kalendorių naudojant tą patį failo vardą.';
$lang['l_delete_cal']		= 'Ištrinti kalendorių';
$lang['l_logout']			= 'Atsijungti';
$lang['l_cal_file']			= 'Kalendoriaus failas';
$lang['l_php_error']		= 'PHP klaida';
$upload_error_gen_lang		= 'Nepavyko nusiųsti failo į serverį.';
$upload_error_lang[0]		= 'Nepavyko nusiųsti failo į serverį.';
$upload_error_lang[1]		= 'Siunčiamas failas yra per didelis.';
$upload_error_lang[2]		= 'Siunčiamas failas yra per didelis.';
$upload_error_lang[3]		= 'Pavyko nusiųsti tik dalį failo.';
$upload_error_lang[4]		= 'Turite pasirinkti failą siuntimui.';
$lang['l_upload_error_type'] = 'Galima siųsti tik .ics failus.';
$lang['l_copy_error']			= 'Nepavyko nukopijuoti failo';
$lang['l_delete_error']			= 'Nepavyko ištrinti failo';
$lang['l_delete_success']		= 'buvo sėkmingai ištrintas.';
$lang['l_action_success']		= 'Veiksmas buvo sėkmingas.';
$lang['l_submit']				= 'Gerai';
$lang['l_delete']				= 'Ištrinti';
$all_cal_comb_lang			= 'Visi kalendoriai';

// New for 2.0
$lang['l_legend']			= 'Paaiškinimai';
$lang['l_admin_subhead']	= 'Šiame puslapyje tvarkykite savo kalendorius';
$lang['l_prefs_subhead']	= 'Nustato slapuką šio puslapio aplankymui';
$lang['l_rss_info']			= 'RSS Informacija';
$lang['l_rss_subhead']		= 'Pagrindiniai RSS vaizdai kiekvienam kalendoriui yra šie';
$lang['l_rss_notenabled']	= 'RSS šioje svetainėje neįjungtas';

// - navigation
$lang['l_back'] 		= 'Atgal';
$lang['l_next'] 		= 'Kitas';
$lang['l_prev'] 		= 'Ankstesnis';
$lang['l_day_view'] 	= 'Diena';
$lang['l_week_view'] 	= 'Savaitė';
$lang['l_month_view'] 	= 'Mėnuo';
$lang['l_year_view'] 	= 'Metai';

// ---------------------------------


// $format_recur, items enclosed in % will be substituted with variables
$format_recur_lang['delimiter']	= ', ';								// ie, 'one, two, three'

$format_recur_lang['yearly']		= array('metus','metus');		// for these, put singular
$format_recur_lang['monthly']		= array('mėnesį','mėnesius');		// and plural forms
$format_recur_lang['weekly']		= array('savaitę','savaites');		// these will be %freq%
$format_recur_lang['daily']			= array('dieną','dienas');			// in the replacement below
$format_recur_lang['hourly']		= array('valandą','valandas');
$format_recur_lang['minutely']		= array('minutę','minutes');
$format_recur_lang['secondly']		= array('sekundę','sekundes');

$format_recur_lang['start']			= 'Kas %int% %freq% %for%';	// ie, 'Every 1 day until January 4' or 'Every 1 day for a count of 5'
$format_recur_lang['until']			= 'iki %date%';				// ie, 'until January 4'
$format_recur_lang['count']			= '%int% kartus';		// ie, 'for 5 times'

$format_recur_lang['bymonth']		= 'Mėnesiais: %list%';			// ie, 'In months: January, February, March'
$format_recur_lang['bymonthday']	= 'Mėnesio dienomis: %list%';			// ie, 'On dates: 1, 2, 3, 4'
$format_recur_lang['byday']			= 'Savaitės dienomis: %list%';			// ie, 'On days: Mon, Tues, Wed, Thurs'

// ---------------------------------

$daysofweek_lang			= array ('Sekmadienis','Pirmadienis','Antradienis','Trečiadienis','Ketvirtadienis','Penktadienis','Šeštadienis');
$daysofweekshort_lang		= array ('Sk','Pr','An','Tr','Kt','Pn','Št');
$daysofweekreallyshort_lang	= array ('S','P','A','T','K','P','Š');
$monthsofyear_lang			= array ('Sausio','Vasario','Kovo','Balandžio','Gegužės','Birželio','Liopos','Rugpjūčio','Rugsėjo','Spalio','Lapkričio','Gruodžio');
$monthsofyearshort_lang		= array ('Sau','Vas','Kov','Bal','Geg','Bir','Lie','Rgp','Rgs','Spa','Lap','Gru');

// For time formatting, check out: http://www.php.net/manual/en/function.date.php
$timeFormat = 'G:i';
$timeFormat_small = 'G:i';

// For date formatting, see note below
$dateFormat_day = '%A, %B %e d.';
$dateFormat_week = '%B %e d.';
$dateFormat_week_list = '%b %e d., %a';
$dateFormat_week_jump = '%b %e d.';
$dateFormat_month = '%Y m. %b mėn.';
$dateFormat_month_list = '%A, %B %e d.';
$dateFormat_year = '%Y';

/*
Notes about dateFormat_*
	The pieces are similar to that of the PHP function strftime(), 
	however only the following is supported at this time:
	
	%A - the full week day name as specified in $daysofweek_lang
	%a - the shortened week day name as specified in $daysofweekshort_lang
	%B - the full month name as specified in $monthsofyear_lang
	%b - the shortened month name as specified in $monthsofyearshort_lang
	%e - the day of the month as a decimal number (1 to 31)
	%Y - the 4-digit year

	If this causes problems with representing your language accurately, let
	us know. We will be happy to modify this if needed.
*/

// Error messages - %s will be replaced with a variable
$lang['l_error_title'] 			= 'Klaida!';
$lang['l_error_window'] 		= 'Įvyko klaida!';
$lang['l_error_calendar'] 		= 'Kalendorius "%s" buvo keičiamas, kai ši klaida įvyko.';
$lang['l_error_path'] 			= 'Nerastas toks kelias: "%s"';
$lang['l_error_back'] 			= 'Norėdami grįžti atgal, apauskite "Back".';
$lang['l_error_remotecal'] 		= 'Serveris nepriima nutolusių nepatvirtintų kalendorių.';
$lang['l_error_restrictedcal'] 	= 'Pabandėte pasiekti uždraustą kalendorių šiame serveryje.';
$lang['l_error_invalidcal'] 	= 'kalendoriaus failas. Pabandykite kitą.';
$lang['l_error_cantopen'] 		= 'Nepavyko atidaryti kalendoriaus.';
$lang['l_error_cache']			= 'Nepavyko rašyti į kešo katalogą. Pasitikrinkite konfigūraciją.';

?>
